# Source(py2): https://hg.python.org/cpython/file/2.7/Lib/chunk.py
# Source(py3): https://github.com/python/cpython/blob/master/Lib/chunk.py

from typing import IO

class Chunk:
    closed = ...  # type: bool
    align = ...  # type: bool
    file = ...  # type: IO[bytes]
    chunkname = ...  # type: bytes
    chunksize = ...  # type: int
    size_read = ...  # type: int
    offset = ...  # type: int
    seekable = ...  # type: bool
    def __init__(self, file: IO[bytes], align: bool = ..., bigendian: bool = ..., inclheader: bool = ...) -> None: ...
    def getname(self) -> bytes: ...
    def getsize(self) -> int: ...
    def close(self) -> None: ...
    def isatty(self) -> bool: ...
    def seek(self, pos: int, whence: int = ...) -> None: ...
    def tell(self) -> int: ...
    def read(self, size: int = ...) -> bytes: ...
    def skip(self) -> None: ...
